@@ -2,6 +2,10 @@
 
 config.addonManager.enable        =
 "Whether the addon manager is enabled or not."
+config.addonManager.repositoryBranch =
+"Specifies the git branch used by the addon manager."
+config.addonManager.repositoryPath =
+"Specifies the git path used by the addon manager."
 config.runtime.version            =
 "Lua runtime version."
 config.runtime.path               =
