@@ -1,10 +1,16 @@
-local codeFormat = require("code_format")
 local files      = require("files")
 local log        = require("log")
 
 return function(uri, options)
-    local text = files.getText(uri)
-    local ast = files.getState(uri)
+    local suc, codeFormat = pcall(require, "code_format")
+    if not suc then
+        return
+    end
+    local text = files.getOriginText(uri)
+    local state = files.getState(uri)
+    if not state then
+        return
+    end
     local status, formattedText = codeFormat.format(uri, text, options)
 
     if not status then
@@ -17,8 +23,8 @@ return function(uri, options)
 
     return {
         {
-            start = ast.ast.start,
-            finish = ast.ast.finish,
+            start = state.ast.start,
+            finish = state.ast.finish,
             text = formattedText,
         }
     }
