@@ -321,9 +321,11 @@ local function checkTableShape(parent, child, uri, mark, errs)
             if myKeys[key] then
                 ok = vm.isSubType(uri, myKeys[key], nodeField, mark, errs)
                 if ok == false then
-                    errs[#errs+1] = 'TYPE_ERROR_PARENT_ALL_DISMATCH' -- error display can be greatly improved
-                    errs[#errs+1] = myKeys[key]
-                    errs[#errs+1] = nodeField
+                    if errs then
+                        errs[#errs+1] = 'TYPE_ERROR_PARENT_ALL_DISMATCH' -- error display can be greatly improved
+                        errs[#errs+1] = myKeys[key]
+                        errs[#errs+1] = nodeField
+                    end
                     failedCheck = true
                 end
             elseif not nodeField:isNullable() then
@@ -337,7 +339,7 @@ local function checkTableShape(parent, child, uri, mark, errs)
         end
         ::continue::
     end
-    if #missedKeys > 0 then
+    if errs and #missedKeys > 0 then
         errs[#errs+1] = 'DIAG_MISSING_FIELDS'
         errs[#errs+1] = parent
         errs[#errs+1] = table.concat(missedKeys, ', ')
@@ -584,9 +586,13 @@ function vm.isSubType(uri, child, parent, mark, errs)
     local x = '' --> `string` set to `A`
     ]]
     if  guide.isBasicType(childName)
-    and guide.isLiteral(child)
-    and vm.isSubType(uri, parentName, childName, mark) then
-        return true
+    and not mark[childName] then
+        mark[childName] = true
+        if vm.isSubType(uri, parentName, childName, mark) then
+            mark[childName] = nil
+            return true
+        end
+        mark[childName] = nil
     end
 
     if errs then
@@ -615,6 +621,7 @@ end
 ---@return vm.node?
 function vm.getTableValue(uri, tnode, knode, inversion)
     local result = vm.createNode()
+    local inferSize = config.get(uri, "Lua.type.inferTableSize")
     for tn in tnode:eachObject() do
         if tn.type == 'doc.type.table' then
             for _, field in ipairs(tn.fields) do
@@ -657,7 +664,7 @@ function vm.getTableValue(uri, tnode, knode, inversion)
                 end
                 if  field.type == 'tableexp'
                 and field.value
-                and field.tindex == 1 then
+                and field.tindex <= inferSize then
                     if inversion then
                         if vm.isSubType(uri, 'integer', knode) then
                             result:merge(vm.compileNode(field.value))
@@ -721,7 +728,7 @@ function vm.getTableKey(uri, tnode, vnode, reverse)
                 if field.type == 'tablefield' then
                     result:merge(vm.declareGlobal('type', 'string'))
                 end
-                if field.type == 'tableexp' then
+                if field.type == 'tableexp' or field.type == 'varargs' then
                     result:merge(vm.declareGlobal('type', 'integer'))
                 end
             end
